@@ -9,6 +9,7 @@ from django.contrib.auth.models import User, Group
 from django.contrib.auth.forms import AdminPasswordChangeForm
 from django.contrib.auth.admin import UserAdmin as UserAdminBase, GroupAdmin as GroupAdminBase
 from django.contrib import admin, auth
+from django.contrib.admin.utils import flatten_fieldsets
 from django.core.exceptions import PermissionDenied
 from django.core.urlresolvers import reverse
 from django.core.mail import send_mail
@@ -259,7 +260,7 @@ class UserAdmin(UserAdminBase, AdminBase):
         # Process the form.
         InviteForm = self.get_form(request,
             form = self.invite_form,
-            fields = admin.util.flatten_fieldsets(self.invite_fieldsets),
+            fields = flatten_fieldsets(self.invite_fieldsets),
         )
         if request.method == "POST":
             form = InviteForm(request.POST)
